==> eiffelstudio-16.05.tar: F_code/C19/xm904.c <==
/*
 * Code for class XM_XPATH_XPOINTER_ELEMENT_SCHEME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm904.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.make */
void F1775_17062 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.expanded_name */

EIF_REFERENCE F1775_17063 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (17063,RTMS_EX_H("element",7,1343925364));
}

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.value */
EIF_REFERENCE F1775_17064 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.were_resources_found */
EIF_BOOLEAN F1775_17065 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_2_3_);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.is_error */
EIF_BOOLEAN F1775_17066 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.evaluate */
void F1775_17067 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTLD;
	
	RTLI(10);
	RTLR(0,Current);
	RTLR(1,arg3);
	RTLR(2,loc6);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,arg1);
	RTLR(6,tr2);
	RTLR(7,tr3);
	RTLR(8,tr4);
	RTLR(9,loc5);
	RTLIU(10);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_3_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	F1775_17070(Current, arg3);
	RTCT0("postcondition_of_parse", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc6 = tr1;
	if (EIF_TEST(loc6)) {
		RTCK0;
	} else {
		RTCF0;
	}
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			tb1 = '\01';
			if (!*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9363[Dtype(loc6)-1392])(loc6);
				tb1 = (EIF_BOOLEAN) (loc1 > ti4_1);
			}
			if (tb1) break;
			if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) && (EIF_BOOLEAN)(loc1 == ((EIF_INTEGER_32) 1L)))) {
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9479[Dtype(loc6)-1415])(loc6, ((EIF_INTEGER_32) 1L));
				loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R13376[Dtype(arg1)-1786])(RTCW(arg1), tr1);
				if ((EIF_BOOLEAN)(loc4 == NULL)) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
					tr1 = RTLNS(eif_new_type(1803, 0x00).id, 1803, _OBJSIZ_7_37_0_1_0_0_0_0_);
					tr2 = RTMS_EX_H("Element not located by shorthand",32,2100082276);
					tr3 = RTOSCF(9327,F1146_9327,(Current));
					tr4 = RTMS_EX_H("XPOINTER_ELEMENT",16,938542164);
					F1804_17811(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 1L));
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
				}
			} else {
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9479[Dtype(loc6)-1415])(loc6, loc1);
				loc3 = F1028_5932(RTCW(tr1));
				if ((EIF_BOOLEAN)(loc4 == NULL)) {
					tr1 = RTOSCF(17053,F1773_17053,(Current));
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE)) R13322[Dtype(arg1)-1776])(RTCW(arg1), ((EIF_INTEGER_32) 4L), tr1);
				} else {
					tr1 = RTOSCF(17053,F1773_17053,(Current));
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE)) R13322[Dtype(loc4)-1776])(RTCW(loc4), ((EIF_INTEGER_32) 4L), tr1);
				}
				loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
				(FUNCTION_CAST(void, (EIF_REFERENCE)) R10521[Dtype(loc5)-1558])(RTCW(loc5));
				for (;;) {
					tb2 = '\01';
					if (!(EIF_BOOLEAN)(loc2 == loc3)) {
						tb3 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10508[Dtype(loc5)-1559])(RTCW(loc5));
						tb2 = tb3;
					}
					if (tb2) break;
					loc2++;
					if ((EIF_BOOLEAN)(loc2 == loc3)) {
						loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10501[Dtype(loc5)-1559])(RTCW(loc5));
						loc4 = RTRV(eif_new_type(1784, 0x00), loc4);
					} else {
						(FUNCTION_CAST(void, (EIF_REFERENCE)) R10522[Dtype(loc5)-1559])(RTCW(loc5));
					}
				}
				if ((EIF_BOOLEAN)(loc2 != loc3)) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
					tr1 = RTLNS(eif_new_type(1803, 0x00).id, 1803, _OBJSIZ_7_37_0_1_0_0_0_0_);
					tr2 = RTMS_EX_H("Element not located by child sequence",37,1926872677);
					tr3 = RTOSCF(9327,F1146_9327,(Current));
					tr4 = RTMS_EX_H("XPOINTER_ELEMENT",16,938542164);
					F1804_17811(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 1L));
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
				}
			}
			loc1++;
		}
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_3_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			tr1 = RTLNS(eif_new_type(1793, 0x00).id, 1793, _OBJSIZ_7_37_0_1_0_0_0_0_);
			F1794_17642(RTCW(tr1), loc4);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
		} else {
		}
	} else {
		tr1 = RTLNS(eif_new_type(1803, 0x00).id, 1803, _OBJSIZ_7_37_0_1_0_0_0_0_);
		tr2 = RTMS_EX_H("Parse error in scheme data",26,1338083681);
		tr3 = RTOSCF(9327,F1146_9327,(Current));
		tr4 = RTMS_EX_H("XPOINTER_ELEMENT",16,938542164);
		F1804_17811(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 1L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.components */
EIF_REFERENCE F1775_17069 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.parse */
void F1775_17070 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,loc3);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	tr1 = RTLNS(eif_new_type(1171, 0x00).id, 1171, _OBJSIZ_2_2_0_0_0_0_0_0_);
	F1172_10080(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("/",1,47);
	F1172_10086(RTCW(loc1), tr1);
	loc3 = F1172_10090(RTCW(loc1), arg1);
	RTAR(Current, loc3);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc3;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9363[Dtype(loc3)-1392])(RTCW(loc3));
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L))) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			tb1 = '\01';
			if (!*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9363[Dtype(loc3)-1392])(RTCW(loc3));
				tb1 = (EIF_BOOLEAN) (loc2 > ti4_1);
			}
			if (tb1) break;
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9479[Dtype(loc3)-1415])(RTCW(loc3), loc2);
			tb2 = F1028_5898(RTCW(tr1));
			if ((EIF_BOOLEAN) !tb2) {
				tb2 = '\0';
				if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 1L))) {
					tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9479[Dtype(loc3)-1415])(RTCW(loc3), ((EIF_INTEGER_32) 1L));
					tb2 = F164_1401(Current, tr1);
				}
				if (tb2) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				} else {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				}
			}
			loc2++;
		}
	}
	RTLE;
}

void EIF_Minit904 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C19/xm904.c <==
/*
 * Code for class XM_XPATH_XPOINTER_ELEMENT_SCHEME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm904.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.make */
void F1775_17093 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.expanded_name */

EIF_REFERENCE F1775_17094 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (17094,RTMS_EX_H("element",7,1343925364));
}

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.value */
EIF_REFERENCE F1775_17095 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.were_resources_found */
EIF_BOOLEAN F1775_17096 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_2_3_);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.is_error */
EIF_BOOLEAN F1775_17097 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.evaluate */
void F1775_17098 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTLD;
	
	RTLI(11);
	RTLR(0,Current);
	RTLR(1,arg3);
	RTLR(2,loc6);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,arg1);
	RTLR(6,tr2);
	RTLR(7,tr3);
	RTLR(8,tr4);
	RTLR(9,loc5);
	RTLR(10,loc7);
	RTLIU(11);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_3_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	F1775_17101(Current, arg3);
	RTCT0("postcondition_of_parse", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc6 = tr1;
	if (EIF_TEST(loc6)) {
		RTCK0;
	} else {
		RTCF0;
	}
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			tb1 = '\01';
			if (!*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9344[Dtype(loc6)-1392])(loc6);
				tb1 = (EIF_BOOLEAN) (loc1 > ti4_1);
			}
			if (tb1) break;
			if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) && (EIF_BOOLEAN)(loc1 == ((EIF_INTEGER_32) 1L)))) {
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9460[Dtype(loc6)-1415])(loc6, ((EIF_INTEGER_32) 1L));
				loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R13359[Dtype(arg1)-1786])(RTCW(arg1), tr1);
				if ((EIF_BOOLEAN)(loc4 == NULL)) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
					tr1 = RTLNS(eif_new_type(1803, 0x00).id, 1803, _OBJSIZ_7_37_0_1_0_0_0_0_);
					tr2 = RTMS_EX_H("Element not located by shorthand",32,2100082276);
					tr3 = RTOSCF(9585,F1198_9585,(Current));
					tr4 = RTMS_EX_H("XPOINTER_ELEMENT",16,938542164);
					F1804_17842(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 1L));
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
				}
			} else {
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9460[Dtype(loc6)-1415])(loc6, loc1);
				loc3 = F1077_6132(RTCW(tr1));
				if ((EIF_BOOLEAN)(loc4 == NULL)) {
					tr1 = RTOSCF(17084,F1773_17084,(Current));
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE)) R13305[Dtype(arg1)-1776])(RTCW(arg1), ((EIF_INTEGER_32) 4L), tr1);
				} else {
					tr1 = RTOSCF(17084,F1773_17084,(Current));
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE)) R13305[Dtype(loc4)-1776])(RTCW(loc4), ((EIF_INTEGER_32) 4L), tr1);
				}
				loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
				(FUNCTION_CAST(void, (EIF_REFERENCE)) R10504[Dtype(loc5)-1558])(RTCW(loc5));
				for (;;) {
					tb2 = '\01';
					if (!(EIF_BOOLEAN)(loc2 == loc3)) {
						tb3 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10491[Dtype(loc5)-1559])(RTCW(loc5));
						tb2 = tb3;
					}
					if (tb2) break;
					loc2++;
					if ((EIF_BOOLEAN)(loc2 == loc3)) {
						tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10484[Dtype(loc5)-1559])(RTCW(loc5));
						loc7 = tr1;
						loc7 = RTRV(eif_new_type(1784, 0x00),loc7);
						if (EIF_TEST(loc7)) {
							loc4 = (EIF_REFERENCE) loc7;
						} else {
							loc4 = (EIF_REFERENCE) NULL;
						}
					} else {
						(FUNCTION_CAST(void, (EIF_REFERENCE)) R10505[Dtype(loc5)-1559])(RTCW(loc5));
					}
				}
				if ((EIF_BOOLEAN)(loc2 != loc3)) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
					tr1 = RTLNS(eif_new_type(1803, 0x00).id, 1803, _OBJSIZ_7_37_0_1_0_0_0_0_);
					tr2 = RTMS_EX_H("Element not located by child sequence",37,1926872677);
					tr3 = RTOSCF(9585,F1198_9585,(Current));
					tr4 = RTMS_EX_H("XPOINTER_ELEMENT",16,938542164);
					F1804_17842(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 1L));
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
				}
			}
			loc1++;
		}
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_3_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			tr1 = RTLNS(eif_new_type(1793, 0x00).id, 1793, _OBJSIZ_7_37_0_1_0_0_0_0_);
			F1794_17673(RTCW(tr1), loc4);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
		} else {
		}
	} else {
		tr1 = RTLNS(eif_new_type(1803, 0x00).id, 1803, _OBJSIZ_7_37_0_1_0_0_0_0_);
		tr2 = RTMS_EX_H("Parse error in scheme data",26,1338083681);
		tr3 = RTOSCF(9585,F1198_9585,(Current));
		tr4 = RTMS_EX_H("XPOINTER_ELEMENT",16,938542164);
		F1804_17842(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 1L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.components */
EIF_REFERENCE F1775_17100 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XPATH_XPOINTER_ELEMENT_SCHEME}.parse */
void F1775_17101 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,loc3);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	tr1 = RTLNS(eif_new_type(1224, 0x00).id, 1224, _OBJSIZ_2_2_0_0_0_0_0_0_);
	F1225_10397(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("/",1,47);
	F1225_10403(RTCW(loc1), tr1);
	loc3 = F1225_10407(RTCW(loc1), arg1);
	RTAR(Current, loc3);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc3;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9344[Dtype(loc3)-1392])(RTCW(loc3));
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L))) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			tb1 = '\01';
			if (!*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9344[Dtype(loc3)-1392])(RTCW(loc3));
				tb1 = (EIF_BOOLEAN) (loc2 > ti4_1);
			}
			if (tb1) break;
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9460[Dtype(loc3)-1415])(RTCW(loc3), loc2);
			tb2 = F1077_6098(RTCW(tr1));
			if ((EIF_BOOLEAN) !tb2) {
				tb2 = '\0';
				if ((EIF_BOOLEAN)(loc2 == ((EIF_INTEGER_32) 1L))) {
					tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R9460[Dtype(loc3)-1415])(RTCW(loc3), ((EIF_INTEGER_32) 1L));
					tb2 = F165_1432(Current, tr1);
				}
				if (tb2) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				} else {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				}
			}
			loc2++;
		}
	}
	RTLE;
}

void EIF_Minit904 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
